aboutsummaryrefslogtreecommitdiff
path: root/travis
diff options
context:
space:
mode:
authorMichael Stapelberg <stapelberg@users.noreply.github.com>2021-05-23 15:44:28 +0200
committerGitHub <noreply@github.com>2021-05-23 15:44:28 +0200
commitc94f41b2dacbd3d953eb1e2c4f71b69b95ceb8bf (patch)
tree878422a49e4755510482c47117af7ab27688350e /travis
parente44aa7a9a9c2b6b1ec067b5baf2eec1c209d84b2 (diff)
downloadi3-c94f41b2dacbd3d953eb1e2c4f71b69b95ceb8bf.tar.gz
i3-c94f41b2dacbd3d953eb1e2c4f71b69b95ceb8bf.zip
switch from Travis to GitHub actions for continuous integration (CI) (#4428)
Diffstat (limited to 'travis')
-rwxr-xr-xtravis/skip-pkg.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/travis/skip-pkg.sh b/travis/skip-pkg.sh
index 4337120b..0ca1d749 100755
--- a/travis/skip-pkg.sh
+++ b/travis/skip-pkg.sh
@@ -2,11 +2,11 @@
# Returns true if Debian/Ubuntu packages should be skipped because this CI run
# was triggered by a pull request.
# Verify BINTRAY_USER is present (only set on github.com/i3/i3),
# otherwise the CI run was triggered by a pull request.
# Verify CC=gcc so that we only build packages once for each commit,
# not twice (with gcc and clang).
-if [ ! -z "$BINTRAY_USER" ] && [ "$CC" = "gcc" ]
+if [ ! -z "$BALTO_TOKEN" ] && [ "$CC" = "gcc" ]
then
exit 1
fi
@@ -2,11 +2,11 @@
# Returns true if Debian/Ubuntu packages should be skipped because this CI run
# was triggered by a pull request.
-# Verify BINTRAY_USER is present (only set on github.com/i3/i3),
+# Verify BALTO_TOKEN is present (only set on github.com/i3/i3),
# otherwise the CI run was triggered by a pull request.
# Verify CC=gcc so that we only build packages once for each commit,